# Programme d'Addition,multiplication et division de Nombres

Ce programme Python contient une fonction `addition_des_nombres` qui prend deux nombres en paramètres, les additionne, puis imprime le résultat.

## Utilisation

Pour utiliser la fonction avec des exemples, vous pouvez faire appel à la fonction avec différentes valeurs.

Exemple :

```python
python
from votre_script import addition_des_nombres

# Appel de la fonction avec les valeurs 30 et 78
addition_des_nombres(30, 78)

multiplication_des_nombres(30, 78)

